@@ -63,6 +63,12 @@ prepare_table <- function(data1,
                            ~ forcats::fct_infreq(.x)))
   }
 
+  if(freq_relevel && !by_group){
+    data1 <- data1 %>%
+      dplyr::mutate(across(where(is.factor),
+                           ~ forcats::fct_infreq(.x)))
+  }
+
 
   if(drop_levels){
     data1 <- data1 %>%
